tests Package
=============

:mod:`test_config` Module
-------------------------

.. automodule:: CMFDefault.browser.admin.tests.test_config
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_syndication` Module
------------------------------

.. automodule:: CMFDefault.browser.admin.tests.test_syndication
    :members:
    :undoc-members:
    :show-inheritance:

